@@ -2,8 +2,17 @@
 #' @param high.order.as.measr Should higher order measurement model be
 #'   denoted with the \code{=~} operator? If \code{FALSE} the \code{~}
 #'   operator is used.
+#' @param rm.tmp.ov Should temporary (hidden) variables be removed?
+#' @param label.renamed.prod Should renamed product terms keep their old (implicit) labels?
+#' @param is.public Should public version of parameter table be returned?
+#'   If \code{FALSE}, the internal version of the parameter table is returned.
 #' @describeIn parameter_estimates Get parameter estimates of a \code{\link{modsem_da}} object
-parameter_estimates.modsem_da <- function(object, high.order.as.measr = TRUE, ...) {
+parameter_estimates.modsem_da <- function(object,
+                                          high.order.as.measr = TRUE,
+                                          is.public = TRUE,
+                                          rm.tmp.ov = is.public,
+                                          label.renamed.prod = NULL, # capture
+                                          ...) {
   parTable <- object$parTable
 
   if (high.order.as.measr) {
@@ -13,7 +22,10 @@ parameter_estimates.modsem_da <- function(object, high.order.as.measr = TRUE, ..
     parTable <- sortParTableDA(parTable, model = object$model)
   }
 
-  parTable
+  if (rm.tmp.ov)
+    parTable <- removeTempOV_RowsParTable(parTable)
+
+  modsemParTable(parTable, is.public = is.public)
 }
 
 
@@ -757,7 +769,7 @@ vcov.modsem_da <- function(object, type = c("all", "free"), ...) {
   type <- match.arg(type)
 
   what <- ifelse(type == "all", yes = "vcov.all", no = "vcov.free")
-  modsem_inspect_da(object, what = what)
+  modsem_inspect_da(object, what = what, ...)
 }
 
 
@@ -769,7 +781,7 @@ coefficients.modsem_da <- function(object, type = c("all", "free"), ...) {
 
   what <- ifelse(type == "all", yes = "coefficients.all",
                  no = "coefficients.free")
-  modsem_inspect_da(object, what = what)
+  modsem_inspect_da(object, what = what, ...)
 }
 
 
@@ -793,22 +805,27 @@ nobs.modsem_da <- function(object, ...) {
 #' standard errors; if \code{FALSE}, use the delta method (default).
 #' @param mc.reps Number of Monte Carlo repetitions. Default is 10000.
 #' @param tolerance.zero Threshold below which standard errors are set to \code{NA}.
+#' @param rm.tmp.ov Should temporary (hidden) variables be removed?
 #'
 #' @export
 standardized_estimates.modsem_da <- function(object,
                                              monte.carlo = FALSE,
                                              mc.reps = 10000,
                                              tolerance.zero = 1e-10,
+                                             rm.tmp.ov = TRUE,
                                              ...) {
-  stdSolution <- standardizedSolutionCOEFS(
+  parTable.std <- standardizedSolutionCOEFS(
     object,
     monte.carlo = monte.carlo,
     mc.reps = mc.reps,
     tolerance.zero = tolerance.zero,
     ...
-  )
+  )$parTable
 
-  stdSolution$parTable
+  if (rm.tmp.ov)
+    parTable.std <- removeTempOV_RowsParTable(parTable.std)
+
+  parTable.std
 }
 
 
@@ -861,8 +878,8 @@ modsem_predict.modsem_da <- function(object, standardized = FALSE, H0 = TRUE, ne
 
   transform.x <- if (center.data) \(x) x - mean(x, na.rm = TRUE) else \(x) x
 
-  parTableH1 <- parameter_estimates(modelH1)
-  parTableH0 <- parameter_estimates(modelH0)
+  parTableH1 <- parameter_estimates(modelH1, is.public = FALSE)
+  parTableH0 <- parameter_estimates(modelH0, is.public = FALSE)
 
   parTableH1 <- addMissingGroups(parTableH1)
   parTableH0 <- addMissingGroups(parTableH0)
@@ -877,11 +894,11 @@ modsem_predict.modsem_da <- function(object, standardized = FALSE, H0 = TRUE, ne
     cols.present <- cols %in% colnames(newdata)
     stopif(!all(cols.present), "Missing cols in `newdata`:\n", cols[!cols.present])
 
-    group <- modsem_inspect(modelH0, what = "group")
+    group <- modsem_inspect(modelH0, what = "group", is.public = FALSE)
 
     if (!is.null(group)) {
       group.values <- as.character(newdata[[group]])
-      group.levels <- modsem_inspect(modelH0, what = "group.label")
+      group.levels <- modsem_inspect(modelH0, what = "group.label", is.public = FALSE)
 
       NEWDATA <- lapply(
         X = group.levels,
@@ -897,18 +914,19 @@ modsem_predict.modsem_da <- function(object, standardized = FALSE, H0 = TRUE, ne
                       FUN = \(sub) sub$data$data.full)
   }
 
-  SIGMA <- modsem_inspect(modelH0, what = "cov.ov")
+  SIGMA <- modsem_inspect(modelH0, what = "cov.ov", is.public = FALSE)
   out <- vector("list", length = length(groups))
 
   for (g in groups) {
     parTableH1g <- parTableH1[parTableH1$group == g, , drop = FALSE]
     parTableH0g <- parTableH0[parTableH0$group == g, , drop = FALSE]
 
-    lVs   <- getLVs(parTableH1g)
+    lVs   <- getLVs(parTableH0g)
     sigma <- if (mgroup) SIGMA[[g]] else SIGMA
 
     sigma.inv <- GINV(sigma)
-    lambda    <- getLambdaParTable(parTableH0g, rows = colnames(sigma), cols = lVs)
+    lambda    <- getLambdaParTable(parTableH0g, rows = colnames(sigma), cols = lVs,
+                                   fill.missing = TRUE)
 
     newdata.g <- NEWDATA[[g]]
     X <- apply(as.matrix(newdata.g), MARGIN = 2, FUN = transform.x)
@@ -927,7 +945,7 @@ modsem_predict.modsem_da <- function(object, standardized = FALSE, H0 = TRUE, ne
       Y  <- apply(Y, MARGIN = 2, FUN = \(y) (y - mu(y)) / s(y))
     }
 
-    out[[g]] <- Y
+    out[[g]] <- modsemMatrix(Y, is.public = TRUE)
   }
 
   if (mgroup) out else out[[1L]]
